@@ -404,7 +404,7 @@ public:
   virtual void PreInit()
   {
     Lum::Label       *label;
-    Lum::Panel       *hPanel,*hPanel2;
+    Lum::Panel       *hPanel,*hPanel2,*vPanel;
     Lum::Slider      *slider;
     Lum::Tab         *tab;
 
@@ -435,13 +435,23 @@ public:
 
     label->AddLabel(L"Power saving:",hPanel2);
 
-    slider=new Lum::HSlider();
-    slider->SetFlex(true,false);
+    hPanel->Add(label);
+
+    hPanel->AddSpace();
+
+    vPanel=Lum::VPanel::Create(false,true);
+    vPanel->Add(Lum::Text::Create(L"Poll (s)"));
+    vPanel->AddSpace();
+
+    slider=new Lum::VSlider();
+    slider->SetFlex(false,true);
     slider->SetScale(true);
     slider->SetModel(refreshTime);
-    label->AddLabel(L"Poll (s):",slider);
+    //label->AddLabel(L"Poll (s):",slider);
 
-    hPanel->Add(label);
+    vPanel->Add(slider);
+
+    hPanel->Add(vPanel);
 
     tab->Add(L"Current",hPanel);
 
